@@ -1,5 +1,5 @@
 from enum import auto
-from strenum import LowercaseStrEnum
+from strenum import LowercaseStrEnum, StrEnum
 
 from .region import Region
 from .runtime import Runtime
@@ -7,10 +7,13 @@ from .runtime import Runtime
 
 DEFAULT_ENDPOINT: str = "api.cloud.wherobots.com"  # "api.cloud.wherobots.com"
 STAGING_ENDPOINT: str = "api.staging.wherobots.com"  # "api.staging.wherobots.com"
-DEFAULT_RUNTIME: Runtime = Runtime.SEDONA
+
+DEFAULT_RUNTIME: Runtime = Runtime.TINY
 DEFAULT_REGION: Region = Region.AWS_US_WEST_2
 DEFAULT_READ_TIMEOUT_SECONDS: float = 0.25
-DEFAULT_SESSION_WAIT_TIMEOUT_SECONDS: float = 300
+DEFAULT_SESSION_WAIT_TIMEOUT_SECONDS: float = 900
+DEFAULT_REUSE_SESSION: bool = True
+
 MAX_MESSAGE_SIZE: int = 100 * 2**20  # 100MiB
 PROTOCOL_VERSION: str = "1.0.0"
 
@@ -67,3 +70,39 @@ class GeometryRepresentation(LowercaseStrEnum):
     EWKT = auto()
     EWKB = auto()
     GEOJSON = auto()
+
+
+class AppStatus(StrEnum):
+    PENDING = auto()
+    PREPARING = auto()
+    PREPARE_FAILED = auto()
+    REQUESTED = auto()
+    DEPLOYING = auto()
+    DEPLOY_FAILED = auto()
+    DEPLOYED = auto()
+    INITIALIZING = auto()
+    INIT_FAILED = auto()
+    READY = auto()
+    DESTROY_REQUESTED = auto()
+    DESTROYING = auto()
+    DESTROY_FAILED = auto()
+    DESTROYED = auto()
+
+    def is_starting(self):
+        return self in (
+            AppStatus.PENDING,
+            AppStatus.PREPARING,
+            AppStatus.REQUESTED,
+            AppStatus.DEPLOYING,
+            AppStatus.DEPLOYED,
+            AppStatus.INITIALIZING,
+        )
+
+    def is_terminal_state(self):
+        return self in (
+            AppStatus.PREPARE_FAILED,
+            AppStatus.DEPLOY_FAILED,
+            AppStatus.INIT_FAILED,
+            AppStatus.DESTROY_FAILED,
+            AppStatus.DESTROYED,
+        )
